public class EmployeeDAO {
    private static final String CF_EMPNUM = "empnum";
    private static final String CF_INFO = "info";
    private static final String CF_SALARY = "salary";
    private static final String CF_PERFORMANCE = "performance";

    public static void insertData(String filePath) throws IOException, NoSuchAlgorithmException {
        Table table = HBaseConnectionManager.getConnection().getTable(TableName.valueOf("emp1520"));
        BufferedReader br = new BufferedReader(new FileReader(filePath));
        String line;

        while ((line = br.readLine()) != null) {
            String[] emp = line.split(",");
            if (emp.length < 12) continue;

            String rowKey = generateRowKey(emp[0]);
            Put put = new Put(Bytes.toBytes(rowKey));
            // 设置列族数据（与原HBaseEmpManager.insertData逻辑相同）
            // ... existing column assignments ...
            table.put(put);
        }
        br.close();
        table.close();
    }

    public static void queryById() throws IOException {
        Table table = HBaseConnectionManager.getConnection().getTable(TableName.valueOf("emp1520"));
        Scan scan = new Scan();
        scan.addColumn(Bytes.toBytes(CF_EMPNUM), Bytes.toBytes("empno"));
        ResultScanner scanner = table.getScanner(scan);
        for (Result result : scanner) {
            String empno = Bytes.toString(result.getValue(Bytes.toBytes(CF_EMPNUM), Bytes.toBytes("empno")));
            if (empno != null && Integer.parseInt(empno) > 7500) {
                System.out.println("ID > 7500 Employee: " + empno);
            }
        }
        table.close();
    }

    // 其他查询方法实现（与原HBaseEmpManager逻辑相同）
    // ... existing query methods ...

    private static String generateRowKey(String empno) throws NoSuchAlgorithmException {
        String prefix = empno.substring(0, 3);
        MessageDigest md5 = MessageDigest.getInstance("MD5");
        byte[] digest = md5.digest(prefix.getBytes());
        StringBuilder hexString = new StringBuilder();
        for (byte b : digest) {
            hexString.append(String.format("%02x", b));
        }
        return hexString.substring(0, 4) + empno;
    }
}